from oscar.apps.voucher.abstract_models import (
    AbstractVoucher, AbstractVoucherApplication)


class Voucher(AbstractVoucher):
    pass


class VoucherApplication(AbstractVoucherApplication):
    pass
